Django AIML
===========

|PyPI| |Status| |Python Version| |License|

|Read the Docs| |Tests| |Codecov|

|pre-commit| |Black|

.. |PyPI| image:: https://img.shields.io/pypi/v/django-aiml.svg
   :target: https://pypi.org/project/django-aiml/
   :alt: PyPI
.. |Status| image:: https://img.shields.io/pypi/status/django-aiml.svg
   :target: https://pypi.org/project/django-aiml/
   :alt: Status
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/django-aiml
   :target: https://pypi.org/project/django-aiml
   :alt: Python Version
.. |License| image:: https://img.shields.io/pypi/l/django-aiml
   :target: https://opensource.org/licenses/MIT
   :alt: License
.. |Read the Docs| image:: https://img.shields.io/readthedocs/django-aiml/latest.svg?label=Read%20the%20Docs
   :target: https://django-aiml.readthedocs.io/
   :alt: Read the documentation at https://django-aiml.readthedocs.io/
.. |Tests| image:: https://github.com/jeffmaxey/django-aiml/workflows/Tests/badge.svg
   :target: https://github.com/jeffmaxey/django-aiml/actions?workflow=Tests
   :alt: Tests
.. |Codecov| image:: https://codecov.io/gh/jeffmaxey/django-aiml/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/jeffmaxey/django-aiml
   :alt: Codecov
.. |pre-commit| image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
   :target: https://github.com/pre-commit/pre-commit
   :alt: pre-commit
.. |Black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Black


Features
--------

* TODO


Requirements
------------

* TODO


Installation
------------

You can install *Django AIML* via pip_ from PyPI_:

.. code:: console

   $ pip install django-aiml


Usage
-----

Please see the `Command-line Reference <Usage_>`_ for details.


Contributing
------------

Contributions are very welcome.
To learn more, see the `Contributor Guide`_.


License
-------

Distributed under the terms of the `MIT license`_,
*Django AIML* is free and open source software.


Issues
------

If you encounter any problems,
please `file an issue`_ along with a detailed description.


Credits
-------

This project was generated from `@cjolowicz`_'s `Hypermodern Python Cookiecutter`_ template.

.. _@cjolowicz: https://github.com/cjolowicz
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _MIT license: https://opensource.org/licenses/MIT
.. _PyPI: https://pypi.org/
.. _Hypermodern Python Cookiecutter: https://github.com/cjolowicz/cookiecutter-hypermodern-python
.. _file an issue: https://github.com/jeffmaxey/django-aiml/issues
.. _pip: https://pip.pypa.io/
.. github-only
.. _Contributor Guide: CONTRIBUTING.rst
.. _Usage: https://django-aiml.readthedocs.io/en/latest/usage.html
